@@ -2,8 +2,6 @@ import os
 import sys
 from time import sleep
 
-sys.path.insert(0, os.getcwd())
-
 try:
     from uuid import uuid4
     import sanic.request
@@ -338,7 +336,7 @@ def start_workers(workers: int = CONFIG["CIRCE_WORKERS"]):
     """
     if CONFIG["CIRCE_IMMEDIATE_MODE"]:
         sys.exit("Can't start workers if CIRCE_IMMEDIATE_MODE=1")
-    working_directory = os.path.dirname(os.path.abspath(__file__))
+    working_directory = os.getcwd()
     call(
         ["huey_consumer.py", "circe.tasks.huey", "-w", str(workers)],
         cwd=working_directory,
