@@ -4,7 +4,8 @@ from multiprocessing import cpu_count
 import sys
 from dotenv import load_dotenv
 
-load_dotenv()
+sys.path.append(os.getcwd())
+load_dotenv("{}/.env".format(os.getcwd()))
 
 CONFIG = {
     "CIRCE_HOST": "127.0.0.1",
